@@ -17,7 +17,6 @@ Sorted list implementations:
 from __future__ import print_function
 
 from bisect import bisect_left, bisect_right, insort
-from collections import Sequence, MutableSequence
 from itertools import chain, repeat, starmap
 from math import log
 from operator import add, eq, ne, gt, ge, lt, le, iadd
@@ -27,6 +26,11 @@ from textwrap import dedent
 # BEGIN Python 2/3 Shims
 ###############################################################################
 
+try:
+    from collections.abc import Sequence, MutableSequence
+except ImportError:
+    from collections import Sequence, MutableSequence
+
 from functools import wraps
 from sys import hexversion
 
@@ -195,7 +199,7 @@ class SortedList(MutableSequence):
 
 
     @property
-    def key(self):
+    def key(self):  # pylint: disable=useless-return
         """Function used to extract comparison key from values.
 
         Sorted list compares values directly so the key function is none.
